@@ -11,7 +11,7 @@ fn main() {
     let client = Client::new(keywords, country)
         .with_lang(lang)
         .with_property(property)
-        .with_category(Category::All)
+        .with_category(Category::FoodAndDrink)
         .build();
     let related_queries = RelatedQueries::new(client).get();
     println!("{}", related_queries);
