@@ -1,6 +1,7 @@
 //! A list of keywords to query on Google Trend
 //! Keywords is limited to a maximum of 5 keywords.
 
+use crate::errors::{KeywordMaxCapacity, KeywordMinCapacity};
 use std::fmt::{Display, Formatter, Result};
 
 #[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
@@ -49,18 +50,12 @@ impl From<&'static str> for Keywords {
     }
 }
 
-impl Into<String> for Keywords {
-    fn into(self) -> String {
-        self.keywords.join(",")
-    }
-}
-
 fn check_keywords(keys: Vec<&'static str>) -> Vec<&'static str> {
-    if keys.len() == 0 {
-        panic!("At least one keyword is required !")
+    if keys.is_empty() {
+        Err(KeywordMinCapacity).unwrap()
     }
     if keys.len() > 5 {
-        panic!("The maximum is 5 keywords !")
+        Err(KeywordMaxCapacity).unwrap()
     }
     keys
 }
